@@ -1,5 +1,5 @@
-/* This file is part of tcpview - network connections viewer for Linux
- * Copyright (C) 2017 chipmunk-sm <dannico@linuxmail.org>
+/* This file is part of "TcpView For Linux" - network connections viewer for Linux
+ * Copyright (C) 2021 chipmunk-sm <dannico@linuxmail.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,14 +19,8 @@
 
 #include <pwd.h>
 
-CUserName::CUserName()
-{
-
-}
-
 QString CUserName::GetUserNameString(__uid_t euid, bool bErrorUser)
 {
-
     if(bErrorUser)
         return QString("- error userid -");
 
@@ -35,5 +29,4 @@ QString CUserName::GetUserNameString(__uid_t euid, bool bErrorUser)
         return QString(ptr->pw_name);
 
     return QString::number(euid);
-
 }
